# lammpsio

[![PyPI version](https://img.shields.io/pypi/v/lammpsio.svg)](https://pypi.org/project/lammpsio)
[![PyPI downloads](https://img.shields.io/pypi/dm/lammpsio)](https://pypi.org/project/lammpsio)
[![Conda](https://img.shields.io/conda/dn/conda-forge/lammpsio)](https://anaconda.org/conda-forge/lammpsio)

lammpsio provides a Python interface for reading and writing LAMMPS
data and dump files. It also enables interconversion with HOOMD-blue's
GSD format. This flexible package enables users to work with LAMMPS files
in a variety of ways that improve workflow efficiency and reproducibility.

`lammpsio` is a pure Python package that can be installed using `pip`:

    pip install lammpsio

or `conda`:

    conda install -c conda-forge lammpsio

Our [documentation](https://lammpsio.readthedocs.io) includes installation,
examples, and commands.
